BusyState class
Whether a extension reports the app as busy (settling, loading, animating, ...).
Properties
- estimatedDuration → Duration?
-
Optional estimate for when busy is expected to clear.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBusy → bool
-
truewhen the extension reports an in-flight activity.final - reason → String?
-
Optional human-readable reason (e.g. "navigating", "loading users").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited