JsonSchema class

Opaque holder for a JSON Schema fragment describing a tool's input.

Constructors

JsonSchema(Map<String, Object?> raw)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
raw Map<String, Object?>
The raw JSON Schema fragment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited