BindingVmServiceFake class

Constructors

BindingVmServiceFake(LeonardBinding _binding, {Object? observationFixture})

Properties

hashCode int
The hash code for this object.
no setterinherited
observationFixture Object?
Optional canned observation. When non-null, calls to ext.exploration.core.get_stable_observation return {type: 'Observation', value: (observationFixture as dynamic).body} instead of executing the binding's real handler. Other extensions and extension tools route normally regardless.
final
onDebugEvent Stream<Event>
no setterinherited
onDone Future<void>
no setterinherited
onExtensionEvent Stream<Event>
no setterinherited
onGCEvent Stream<Event>
no setterinherited
onHeapSnapshotEvent Stream<Event>
no setterinherited
onIsolateEvent Stream<Event>
no setterinherited
onLoggingEvent Stream<Event>
no setterinherited
onProfilerEvent Stream<Event>
no setterinherited
onReceive Stream<String>
no setterinherited
onSend Stream<String>
no setterinherited
onServiceEvent Stream<Event>
no setterinherited
onStderrEvent Stream<Event>
no setterinherited
onStdoutEvent Stream<Event>
no setterinherited
onTimelineEvent Stream<Event>
no setterinherited
onVMEvent Stream<Event>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wsUri String?
The web socket URI pointing to the target VM service instance.
finalinherited

Methods

addBreakpoint(String isolateId, String scriptId, int line, {int? column}) Future<Breakpoint>
The addBreakpoint RPC is used to add a breakpoint at a specific line of some script.
inherited
addBreakpointAtEntry(String isolateId, String functionId) Future<Breakpoint>
The addBreakpointAtEntry RPC is used to add a breakpoint at the entrypoint of some function.
inherited
addBreakpointWithScriptUri(String isolateId, String scriptUri, int line, {int? column}) Future<Breakpoint>
The addBreakpoint RPC is used to add a breakpoint at a specific line of some script. This RPC is useful when a script has not yet been assigned an id, for example, if a script is in a deferred library which has not yet been loaded.
inherited
callMethod(String method, {String? isolateId, Map<String, dynamic>? args}) Future<Response>
Call an arbitrary service protocol method. This allows clients to call methods not explicitly exposed by this library.
inherited
callServiceExtension(String method, {String? isolateId, Map<String, dynamic>? args}) Future<Response>
Invoke a specific service protocol extension method.
clearCpuSamples(String isolateId) Future<Success>
Clears all CPU profiling samples.
inherited
clearVMTimeline() Future<Success>
Clears all VM timeline events.
inherited
createIdZone(String isolateId, String backingBufferKind, String idAssignmentPolicy, {int? capacity}) Future<IdZone>
The createIdZone RPC is used to create a new ID zone where temporary IDs for instances in the specified isolate may be allocated. See IDs and Names for more information about ID zones.
inherited
deleteIdZone(String isolateId, String idZoneId) Future<Success>
The deleteIdZone RPC frees the buffer that backs the specified ID zone, and makes that zone unusable for the remainder of the program's execution. For performance reasons, clients should aim to call invalidateIdZone and reuse existing zones as much as possible instead of deleting zones and then creating new ones.
inherited
dispose() Future<void>
evaluate(String isolateId, String targetId, String expression, {Map<String, String>? scope, bool? disableBreakpoints, String? idZoneId}) Future<Response>
The evaluate RPC is used to evaluate an expression in the context of some target.
inherited
evaluateInFrame(String isolateId, int frameIndex, String expression, {Map<String, String>? scope, bool? disableBreakpoints, String? idZoneId}) Future<Response>
The evaluateInFrame RPC is used to evaluate an expression in the context of a particular stack frame. frameIndex is the index of the desired Frame, with an index of 0 indicating the top (most recent) frame.
inherited
getAllocationProfile(String isolateId, {bool? reset, bool? gc}) Future<AllocationProfile>
The getAllocationProfile RPC is used to retrieve allocation information for a given isolate.
inherited
getAllocationTraces(String isolateId, {int? timeOriginMicros, int? timeExtentMicros, String? classId}) Future<CpuSamples>
The getAllocationTraces RPC allows for the retrieval of allocation traces for objects of a specific set of types (see VmService.setTraceClassAllocation). Only samples collected in the time range [timeOriginMicros, timeOriginMicros + timeExtentMicros] will be reported.
inherited
getClassList(String isolateId) Future<ClassList>
The getClassList RPC is used to retrieve a ClassList containing all classes for an isolate based on the isolate's isolateId.
inherited
getCpuSamples(String isolateId, int timeOriginMicros, int timeExtentMicros) Future<CpuSamples>
The getCpuSamples RPC is used to retrieve samples collected by the CPU profiler. See CpuSamples for a detailed description of the response.
inherited
getFlagList() Future<FlagList>
The getFlagList RPC returns a list of all command line flags in the VM along with their current values.
inherited
getInboundReferences(String isolateId, String targetId, int limit, {String? idZoneId}) Future<InboundReferences>
Returns a set of inbound references to the object specified by targetId. Up to limit references will be returned.
inherited
getInstances(String isolateId, String objectId, int limit, {bool? includeSubclasses, bool? includeImplementers, String? idZoneId}) Future<InstanceSet>
The getInstances RPC is used to retrieve a set of instances which are of a specific class.
inherited
getInstancesAsList(String isolateId, String objectId, {bool? includeSubclasses, bool? includeImplementers, String? idZoneId}) Future<InstanceRef>
The getInstancesAsList RPC is used to retrieve a set of instances which are of a specific class. This RPC returns an InstanceRef corresponding to a Dart List<dynamic> that contains the requested instances. This List is not growable, but it is otherwise mutable. The response type is what distinguishes this RPC from getInstances, which returns an InstanceSet.
inherited
getIsolate(String isolateId) Future<Isolate>
The getIsolate RPC is used to lookup an Isolate object by its id.
inherited
getIsolateGroup(String isolateGroupId) Future<IsolateGroup>
The getIsolateGroup RPC is used to lookup an IsolateGroup object by its id.
inherited
getIsolateGroupMemoryUsage(String isolateGroupId) Future<MemoryUsage>
The getIsolateGroupMemoryUsage RPC is used to lookup an isolate group's memory usage statistics by its id.
inherited
getIsolatePauseEvent(String isolateId) Future<Event>
The getIsolatePauseEvent RPC is used to lookup an isolate's pause event by its id.
inherited
getMemoryUsage(String isolateId) Future<MemoryUsage>
The getMemoryUsage RPC is used to lookup an isolate's memory usage statistics by its id.
inherited
getObject(String isolateId, String objectId, {int? offset, int? count, String? idZoneId}) Future<Obj>
The getObject RPC is used to lookup an object from some isolate by its id.
inherited
getPerfettoCpuSamples(String isolateId, {int? timeOriginMicros, int? timeExtentMicros}) Future<PerfettoCpuSamples>
The getPerfettoCpuSamples RPC is used to retrieve samples collected by the CPU profiler, serialized in Perfetto's proto format. See PerfettoCpuSamples for a detailed description of the response.
inherited
getPerfettoVMTimeline({int? timeOriginMicros, int? timeExtentMicros}) Future<PerfettoTimeline>
The getPerfettoVMTimeline RPC is used to retrieve an object which contains a VM timeline trace represented in Perfetto's proto format. See PerfettoTimeline for a detailed description of the response.
inherited
getPorts(String isolateId) Future<PortList>
The getPorts RPC is used to retrieve the list of ReceivePort instances for a given isolate.
inherited
getProcessMemoryUsage() Future<ProcessMemoryUsage>
Returns a description of major uses of memory known to the VM.
inherited
getRetainingPath(String isolateId, String targetId, int limit, {String? idZoneId}) Future<RetainingPath>
The getRetainingPath RPC is used to lookup a path from an object specified by targetId to a GC root (i.e., the object which is preventing this object from being garbage collected).
inherited
getScripts(String isolateId) Future<ScriptList>
The getScripts RPC is used to retrieve a ScriptList containing all scripts for an isolate based on the isolate's isolateId.
inherited
getSourceReport(String isolateId, List<String> reports, {String? scriptId, int? tokenPos, int? endTokenPos, bool? forceCompile, bool? reportLines, List<String>? libraryFilters, List<String>? librariesAlreadyCompiled}) Future<SourceReport>
The getSourceReport RPC is used to generate a set of reports tied to source locations in an isolate.
inherited
getStack(String isolateId, {int? limit, String? idZoneId}) Future<Stack>
The getStack RPC is used to retrieve the current execution stack and message queue for an isolate. The isolate does not need to be paused.
inherited
getSupportedProtocols() Future<ProtocolList>
The getSupportedProtocols RPC is used to determine which protocols are supported by the current server.
inherited
getVersion() Future<Version>
The getVersion RPC is used to determine what version of the Service Protocol is served by a VM.
inherited
getVM() Future<VM>
The getVM RPC returns global information about a Dart virtual machine.
inherited
getVMTimeline({int? timeOriginMicros, int? timeExtentMicros}) Future<Timeline>
The getVMTimeline RPC is used to retrieve an object which contains VM timeline events. See Timeline for a detailed description of the response.
inherited
getVMTimelineFlags() Future<TimelineFlags>
The getVMTimelineFlags RPC returns information about the current VM timeline configuration.
inherited
getVMTimelineMicros() Future<Timestamp>
The getVMTimelineMicros RPC returns the current time stamp from the clock used by the timeline, similar to Timeline.now in dart:developer and Dart_TimelineGetMicros in the VM embedding API.
inherited
invalidateIdZone(String isolateId, String idZoneId) Future<Success>
The invalidateIdZone RPC is used to invalidate all the IDs that have been allocated in a certain ID zone. Invaliding the IDs makes them expire. See IDs and Names for more information.
inherited
invoke(String isolateId, String targetId, String selector, List<String> argumentIds, {bool? disableBreakpoints, String? idZoneId}) Future<Response>
The invoke RPC is used to perform regular method invocation on some receiver, as if by dart:mirror's ObjectMirror.invoke. Note this does not provide a way to perform getter, setter or constructor invocation.
inherited
kill(String isolateId) Future<Success>
The kill RPC is used to kill an isolate as if by dart:isolate's Isolate.kill(IMMEDIATE).
inherited
lookupPackageUris(String isolateId, List<String> uris) Future<UriList>
The lookupPackageUris RPC is used to convert a list of URIs to their unresolved paths. For example, URIs passed to this RPC are mapped in the following ways:
inherited
lookupResolvedPackageUris(String isolateId, List<String> uris, {bool? local}) Future<UriList>
The lookupResolvedPackageUris RPC is used to convert a list of URIs to their resolved (or absolute) paths. For example, URIs passed to this RPC are mapped in the following ways:
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String streamId) Stream<Event>
inherited
pause(String isolateId) Future<Success>
The pause RPC is used to interrupt a running isolate. The RPC enqueues the interrupt request and potentially returns before the isolate is paused.
inherited
registerService(String service, String alias) Future<Success>
Registers a service that can be invoked by other VM service clients, where service is the name of the service to advertise and alias is an alternative name for the registered service.
inherited
registerServiceCallback(String service, ServiceCallback cb) → void
Register a service for invocation.
inherited
reloadSources(String isolateId, {bool? force, bool? pause, String? rootLibUri, String? packagesUri}) Future<ReloadReport>
The reloadSources RPC is used to perform a hot reload of the sources of all isolates in the same isolate group as the isolate specified by isolateId.
inherited
removeBreakpoint(String isolateId, String breakpointId) Future<Success>
The removeBreakpoint RPC is used to remove a breakpoint by its id.
inherited
requestHeapSnapshot(String isolateId) Future<Success>
Requests a dump of the Dart heap of the given isolate.
inherited
resume(String isolateId, {String? step, int? frameIndex}) Future<Success>
The resume RPC is used to resume execution of a paused isolate.
inherited
setBreakpointState(String isolateId, String breakpointId, bool enable) Future<Breakpoint>
The setBreakpointState RPC allows for breakpoints to be enabled or disabled, without requiring for the breakpoint to be completely removed.
inherited
setExceptionPauseMode(String isolateId, String mode) Future<Success>
The setExceptionPauseMode RPC is used to control if an isolate pauses when an exception is thrown.
inherited
setFlag(String name, String value) Future<Response>
The setFlag RPC is used to set a VM flag at runtime. Returns an error if the named flag does not exist, the flag may not be set at runtime, or the value is of the wrong type for the flag.
inherited
setIsolatePauseMode(String isolateId, {String? exceptionPauseMode, bool? shouldPauseOnExit}) Future<Success>
The setIsolatePauseMode RPC is used to control if or when an isolate will pause due to a change in execution state.
inherited
setLibraryDebuggable(String isolateId, String libraryId, bool isDebuggable) Future<Success>
The setLibraryDebuggable RPC is used to enable or disable whether breakpoints and stepping work for a given library.
inherited
setName(String isolateId, String name) Future<Success>
The setName RPC is used to change the debugging name for an isolate.
inherited
setTraceClassAllocation(String isolateId, String classId, bool enable) Future<Success>
The setTraceClassAllocation RPC allows for enabling or disabling allocation tracing for a specific type of object. Allocation traces can be retrieved with the getAllocationTraces RPC.
inherited
setVMName(String name) Future<Success>
The setVMName RPC is used to change the debugging name for the vm.
inherited
setVMTimelineFlags(List<String> recordedStreams) Future<Success>
The setVMTimelineFlags RPC is used to set which timeline streams are enabled.
inherited
streamCancel(String streamId) Future<Success>
The streamCancel RPC cancels a stream subscription in the VM.
inherited
streamCpuSamplesWithUserTag(List<String> userTags) Future<Success>
The streamCpuSamplesWithUserTag RPC allows for clients to specify which CPU samples collected by the profiler should be sent over the Profiler stream. When called, the VM will stream CpuSamples events containing CpuSample's collected while a user tag contained in userTags was active.
inherited
streamListen(String streamId) Future<Success>
The streamListen RPC subscribes to a stream in the VM. Once subscribed, the client will begin receiving events from the stream.
inherited
toString() String
A string representation of this object.
inherited
wrapFuture<T>(String name, Future<T> future) Future<T>
When overridden, this method wraps future with logic.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited