ExecutedAction class
Record of a tool the harness just executed; passed to
LeonardExtension.onActionExecuted.
Constructors
-
ExecutedAction({required String toolName, required Map<
String, Object?> args, required ToolResult result}) -
const
Properties
-
args
→ Map<
String, Object?> -
Arguments the harness invoked the tool with.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → ToolResult
-
Outcome reported by the tool.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
Fully-qualified tool name (
<namespace>.<tool>).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited