RouteSnapshot class
Value-type snapshot of route state — the exact triple the router observation fragment carries.
Constructors
Properties
-
arguments
→ Map<
String, Object?> ? -
The arguments of the top route, or null when it has no Map arguments.
final
- currentRouteName → String?
-
The name of the top route, or null when no named route is present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stack
→ List<
String> -
The route names from bottom to top of the navigation stack.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited