ToolResult class
Outcome of an LeonardTool invocation.
Constructors
- ToolResult({required bool ok, Object? value, String? error})
-
const
Properties
- error → String?
-
Optional error message when ok is
false.final - hashCode → int
-
The hash code for this object.
no setterinherited
- ok → bool
-
Whether the tool ran to completion without error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
Optional payload returned by the tool when ok is
true.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited